package br.com.rhino.user.controller;

import java.util.List;

import br.com.rhino.controller.CommonController;
import br.com.rhino.user.dto.UserDTO;
import br.com.rhino.user.exception.UserNotFoundException;
import br.com.rhino.user.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping(value = "/user", produces = MediaType.APPLICATION_JSON_VALUE)
public class UserController implements CommonController {

    private final UserService userService;

    @Autowired
    public UserController(final UserService userService) {
        this.userService = userService;
    }

    @GetMapping
    public ResponseEntity<List<UserDTO>> findAll() {
        return ResponseEntity.ok().body(userService.findAllUsers());
    }

    @GetMapping("/by-username/")
    public ResponseEntity<UserDTO> findByUsername(@RequestParam("nome") final String nome) {
        try {
            final UserDTO userDTO = userService.findByUsername(nome);
            return ResponseEntity.ok().body(userDTO);
        } catch (UserNotFoundException exception) {
            return handleException(exception);
        }
    }

    @GetMapping("/{id}")
    public ResponseEntity<UserDTO> findById(@PathVariable final Long id) {
        try {
            final UserDTO userDTO = userService.findById(id);
            return ResponseEntity.ok().body(userDTO);
        } catch (UserNotFoundException exception) {
            return handleException(exception);
        }
    }

    @PostMapping
    public ResponseEntity<UserDTO> create(@RequestBody final UserDTO userDTO) {
        final UserDTO userDTOSave = userService.save(userDTO);
        return ResponseEntity.status(HttpStatus.CREATED).body(userDTOSave);
    }

    @PutMapping("/{id}")
    public ResponseEntity<UserDTO> update(@PathVariable final Long id, @RequestBody final UserDTO userDTO) {
        try {
            final UserDTO userDTOSave = userService.update(id, userDTO);
            return ResponseEntity.status(HttpStatus.CREATED).body(userDTOSave);
        } catch (UserNotFoundException exception) {
            return handleException(exception);
        }
    }

    @DeleteMapping("/{id}")
    public void delete(@PathVariable final Long id) {
        userService.delete(id);
    }
}
