package br.com.rhino.user.entity;

import java.time.LocalDateTime;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.persistence.Table;

import io.quarkus.hibernate.orm.panache.PanacheEntityBase;

@Entity
@Table(name = "\"user\"")
public class User extends PanacheEntityBase {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    public Long id;
    @Column(unique = true)
    public String username;
    @Column(unique = true)
    public String email;
    public String password;
    @Column(name = "dt_creation")
    public LocalDateTime createdAt;
    @Column(name = "dt_update")
    public LocalDateTime updatedAt;
    @JoinTable(
            name = "user_roles",
            joinColumns = @JoinColumn(name = "user_id"),
            inverseJoinColumns = @JoinColumn(name = "role_id")
    )
    @OneToMany(cascade = CascadeType.MERGE)
    public Set<Role> roles;

    @PrePersist
    public void prePersist() {
        final LocalDateTime now = LocalDateTime.now();
        createdAt = now;
        updatedAt = now;
    }

    @PreUpdate
    public void preUpdate() {
        updatedAt = LocalDateTime.now();
    }

    public User id(final Long id) {
        this.id = id;
        return this;
    }

    public User username(final String username) {
        this.username = username;
        return this;
    }

    public User email(final String email) {
        this.email = email;
        return this;
    }

    public User password(final String password) {
        this.password = password;
        return this;
    }

    public User roles(final Set<Role> roles) {
        this.roles = roles;
        return this;
    }
}

