-- Schema "rhino"

create TABLE IF NOT EXISTS "rhino"."user" (
 	id serial PRIMARY KEY  ,
	username VARCHAR ( 50 ) UNIQUE NOT NULL,
	password VARCHAR ( 50 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "rhino".roles (
   id serial PRIMARY KEY,
   role_name VARCHAR (255) UNIQUE NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "rhino".permission (
   id serial PRIMARY KEY,
   "name" VARCHAR (155) UNIQUE NOT NULL,
   description VARCHAR (500) NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "rhino".roles_permission (
  permission_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (permission_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "rhino".roles (id),
  FOREIGN KEY (permission_id) REFERENCES "rhino".permission (id)
);

create TABLE IF NOT EXISTS "rhino".user_roles (
  user_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (user_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "rhino".roles (id),
  FOREIGN KEY (user_id) REFERENCES "rhino"."user" (id)
);

create TABLE IF NOT EXISTS "rhino".address (
   id serial PRIMARY KEY,
   number VARCHAR (10) NOT NULL,
   street VARCHAR (400) NOT NULL,
   district VARCHAR (255) NOT NULL,
   zip_code VARCHAR (10) NOT NULL,
   city VARCHAR (255) NOT NULL,
   state VARCHAR (255) NOT NULL,
   dt_creation TIMESTAMP NOT NULL,
   dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "rhino".person_company (
 	id serial PRIMARY KEY ,
 	address_id INT NOT NULL,
	name_company_name VARCHAR ( 50 ) UNIQUE NOT NULL,
	phone VARCHAR ( 11 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (address_id) REFERENCES "rhino".address (id)
);

create TABLE IF NOT EXISTS "rhino".person (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cpf VARCHAR (11) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "rhino".person_company (id)
);

create TABLE IF NOT EXISTS "rhino".company (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cnpj VARCHAR (14) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "rhino".person_company (id)
);

-- Schema "maripa"

create TABLE IF NOT EXISTS "maripa"."user" (
 	id serial PRIMARY KEY  ,
	username VARCHAR ( 50 ) UNIQUE NOT NULL,
	password VARCHAR ( 50 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "maripa".roles (
   id serial PRIMARY KEY,
   role_name VARCHAR (255) UNIQUE NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "maripa".permission (
   id serial PRIMARY KEY,
   "name" VARCHAR (155) UNIQUE NOT NULL,
   description VARCHAR (500) NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "maripa".roles_permission (
  permission_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (permission_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "maripa".roles (id),
  FOREIGN KEY (permission_id) REFERENCES "maripa".permission (id)
);

create TABLE IF NOT EXISTS "maripa".user_roles (
  user_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (user_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "maripa".roles (id),
  FOREIGN KEY (user_id) REFERENCES "maripa"."user" (id)
);

create TABLE IF NOT EXISTS "maripa".address (
   id serial PRIMARY KEY,
   number VARCHAR (10) NOT NULL,
   street VARCHAR (400) NOT NULL,
   district VARCHAR (255) NOT NULL,
   zip_code VARCHAR (10) NOT NULL,
   city VARCHAR (255) NOT NULL,
   state VARCHAR (255) NOT NULL,
   dt_creation TIMESTAMP NOT NULL,
   dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "maripa".person_company (
 	id serial PRIMARY KEY ,
 	address_id INT NOT NULL,
	name_company_name VARCHAR ( 50 ) UNIQUE NOT NULL,
	phone VARCHAR ( 11 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (address_id) REFERENCES "maripa".address (id)
);

create TABLE IF NOT EXISTS "maripa".person (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cpf VARCHAR (11) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "maripa".person_company (id)
);

create TABLE IF NOT EXISTS "maripa".company (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cnpj VARCHAR (14) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "maripa".person_company (id)
);

-- Schema "bicas"

create TABLE IF NOT EXISTS "bicas"."user" (
 	id serial PRIMARY KEY  ,
	username VARCHAR ( 50 ) UNIQUE NOT NULL,
	password VARCHAR ( 50 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "bicas".roles (
   id serial PRIMARY KEY,
   role_name VARCHAR (255) UNIQUE NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "bicas".permission (
   id serial PRIMARY KEY,
   "name" VARCHAR (155) UNIQUE NOT NULL,
   description VARCHAR (500) NOT NULL,
   dt_creation TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "bicas".roles_permission (
  permission_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (permission_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "bicas".roles (id),
  FOREIGN KEY (permission_id) REFERENCES "bicas".permission (id)
);

create TABLE IF NOT EXISTS "bicas".user_roles (
  user_id INT NOT NULL,
  role_id INT NOT NULL,
  PRIMARY KEY (user_id, role_id),
  FOREIGN KEY (role_id) REFERENCES "bicas".roles (id),
  FOREIGN KEY (user_id) REFERENCES "bicas"."user" (id)
);

create TABLE IF NOT EXISTS "bicas".address (
   id serial PRIMARY KEY,
   number VARCHAR (10) NOT NULL,
   street VARCHAR (400) NOT NULL,
   district VARCHAR (255) NOT NULL,
   zip_code VARCHAR (10) NOT NULL,
   city VARCHAR (255) NOT NULL,
   state VARCHAR (255) NOT NULL,
   dt_creation TIMESTAMP NOT NULL,
   dt_update TIMESTAMP NOT NULL
);

create TABLE IF NOT EXISTS "bicas".person_company (
 	id serial PRIMARY KEY ,
 	address_id INT NOT NULL,
	name_company_name VARCHAR ( 50 ) UNIQUE NOT NULL,
	phone VARCHAR ( 11 ) NOT NULL,
	email VARCHAR ( 255 ) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (address_id) REFERENCES "bicas".address (id)
);

create TABLE IF NOT EXISTS "bicas".person (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cpf VARCHAR (11) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "bicas".person_company (id)
);

create TABLE IF NOT EXISTS "bicas".company (
 	id serial PRIMARY KEY ,
 	person_company_id INT NOT NULL,
    cnpj VARCHAR (14) UNIQUE NOT NULL,
    dt_creation TIMESTAMP NOT NULL,
	dt_update TIMESTAMP NOT NULL,
	FOREIGN KEY (person_company_id) REFERENCES "bicas".person_company (id)
);